@@ -24,7 +24,6 @@
 
 #include <KMessageBox>
 #include <KLocalizedString>
-#include <KToolInvocation>
 #include <qdesktopservices.h>
 
 #include "drkonqi.h"
@@ -307,7 +306,7 @@ void BacktraceWidget::loadData()
         ui.m_extraDetailsLabel->setText(xi18nc("@info/rich", "<strong>You need to first install the debugger "
                                                "application (%1) then click the <interface>Reload"
                                                "</interface> button.</strong>",
-                                               m_btGenerator->debugger().name()));
+                                               m_btGenerator->debugger().displayName()));
     }
 
     ui.m_reloadBacktraceButton->setEnabled(true);
@@ -319,7 +318,7 @@ void BacktraceWidget::backtraceNewLine(const QString & line)
 {
     // We absolutely must not have a highlighter attached. The highlighter has
     // a static list of lines to highlight from. When we are loading lines
-    // this static list does not match reality breaking text lenght expecations
+    // this static list does not match reality breaking text length expectations
     // and resulting in segfaults.
     Q_ASSERT(!m_highlighter);
     //While loading the backtrace (unparsed) a new line was sent from the debugger, append it
@@ -339,15 +338,13 @@ void BacktraceWidget::saveClicked()
 
 void BacktraceWidget::hilightExtraDetailsLabel(bool hilight)
 {
-    QString stylesheet;
-    if (hilight) {
-        stylesheet = QLatin1String("border-width: 2px; "
-                                    "border-style: solid; "
-                                    "border-color: red;");
-    } else {
-        stylesheet = QLatin1String("border-width: 0px;");
-    }
-    stylesheet += QLatin1String(extraDetailsLabelMargin);
+    const QString stylesheet = ((!hilight)
+        ? QLatin1String("border-width: 0px;")
+        : QLatin1String("border-width: 2px; "
+                        "border-style: solid; "
+                        "border-color: red;"))
+        + QLatin1String(extraDetailsLabelMargin);
+
     ui.m_extraDetailsLabel->setStyleSheet(stylesheet);
 }
 
@@ -396,12 +393,12 @@ void BacktraceWidget::extraDetailsLinkActivated(QString link)
         missingDbgForFiles.insert(0, DrKonqi::crashedApplication()->executable().absoluteFilePath());
 
         //HTML message
-        QString message = QStringLiteral("<html>");
-        message += i18n("The packages containing debug information for the following application and libraries are missing:");
-        message += QStringLiteral("<br /><ul>");
+        QString message = QStringLiteral("<html>")
+            + i18n("The packages containing debug information for the following application and libraries are missing:")
+            + QStringLiteral("<br /><ul>");
 
         Q_FOREACH(const QString & string, missingDbgForFiles) {
-            message += QStringLiteral("<li>") + string + QStringLiteral("</li>");
+            message += QLatin1String("<li>") + string + QLatin1String("</li>");
         }
 
         message += QStringLiteral("</ul></html>");
